#! /bin/bash

#
# Script name: find_database.sh
#
# Purpose: To determine the main database an application is to use by
#    setting an environment variable, DB.
#
# Usage: This is intended to be used by existing scripts.  For example
#    ...
#    . find_database.sh
#    ...
#    java $DB ...
#
# Notes: The file /cell/site_special is checked for an index line 98.
#    If the file and this line exist, the database will be set to the
#    value from that line.  Otherwise the database will default
#    depending on the network, Cummins or CMX.  These defaults are set
#    for backward compatability.

# Cummins production
database="jdbc:oracle:thin:@acdcslpdb0035.aciz.cummins.com:1527:engopsp"
# Cybermetrix test
if [ `dnsdomainname` = 'nr.cybermetrix.com' ]; then 
   database="jdbc:oracle:thin:@cmx035n:1521:XE"
fi

# See if there's a /cell/site_special file to check.
if [ -e /cell/site_special ]; then
   # Sample line from the site_special file:
   #   98  database  "SITE_SPECIAL" OFF
   # This trims the lhs of the line.
   LINE=`grep '^ *98 ' /cell/site_special`
   # If we found the line for the database jdbc connection information
   # parse it.
   if [ "$LINE" != '' ]; then
      # Get the value field
      STRING=`echo $LINE | tr -s ' ' | cut -f3 -d\ `
      # Trim off the leading and trailing quote marks.
      LENGTH=${#STRING}
      LENGTH=$LENGTH-2
      # Get the value.
      database=${STRING:1:$LENGTH}
   fi
fi

DB=-DdatabaseServer=$database
unset database
